/**
 * Trend Micro Deep Security API
 * Copyright 2018 - 2024 Trend Micro Incorporated.<br/>Get protected, stay secured, and keep informed with Trend Micro Deep Security's new RESTful API. Access system data and manage security configurations to automate your security workflows and integrate Deep Security into your CI/CD pipeline. # Authentication <!-- ReDoc-Inject: <security-definitions> -->
 *
 * OpenAPI spec version: 20.0.904
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.4.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/AWSConnector', 'model/AWSConnectors', 'model/SearchFilter'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/AWSConnector'), require('../model/AWSConnectors'), require('../model/SearchFilter'));
  } else {
    // Browser globals (root is window)
    if (!root.Deepsecurity) {
      root.Deepsecurity = {};
    }
    root.Deepsecurity.AWSConnectorsApi = factory(root.Deepsecurity.ApiClient, root.Deepsecurity.AWSConnector, root.Deepsecurity.AWSConnectors, root.Deepsecurity.SearchFilter);
  }
}(this, function(ApiClient, AWSConnector, AWSConnectors, SearchFilter) {
  'use strict';

  /**
   * AWSConnectors service.
   * @module api/AWSConnectorsApi
   * @version 20.0.904
   */

  /**
   * Constructs a new AWSConnectorsApi. 
   * @alias module:api/AWSConnectorsApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;



    /**
     * Create an AWS Connector
     * Create a new AWS Connector.
     * @param {module:model/AWSConnector} awsConnector The settings of the new AWS Connector.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AWSConnector} and HTTP response
     */
    this.createAWSConnectorWithHttpInfo = function(awsConnector, apiVersion) {
      var postBody = awsConnector;

      // verify the required parameter 'awsConnector' is set
      if (awsConnector === undefined || awsConnector === null) {
        throw new Error("Missing the required parameter 'awsConnector' when calling createAWSConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling createAWSConnector");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AWSConnector;

      return this.apiClient.callApi(
        '/awsconnectors', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Create an AWS Connector
     * Create a new AWS Connector.
     * @param {module:model/AWSConnector} awsConnector The settings of the new AWS Connector.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AWSConnector}
     */
    this.createAWSConnector = function(awsConnector, apiVersion) {
      return this.createAWSConnectorWithHttpInfo(awsConnector, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Delete an AWS Connector
     * Delete an existing AWS Connector by ID.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */
    this.deleteAWSConnectorWithHttpInfo = function(awsConnectorID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'awsConnectorID' is set
      if (awsConnectorID === undefined || awsConnectorID === null) {
        throw new Error("Missing the required parameter 'awsConnectorID' when calling deleteAWSConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling deleteAWSConnector");
      }


      var pathParams = {
        'awsConnectorID': awsConnectorID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = null;

      return this.apiClient.callApi(
        '/awsconnectors/{awsConnectorID}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Delete an AWS Connector
     * Delete an existing AWS Connector by ID.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */
    this.deleteAWSConnector = function(awsConnectorID, apiVersion) {
      return this.deleteAWSConnectorWithHttpInfo(awsConnectorID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Describe an existing AWS Connector
     * Describe an AWS Connector by ID.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AWSConnector} and HTTP response
     */
    this.describeAWSConnectorWithHttpInfo = function(awsConnectorID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'awsConnectorID' is set
      if (awsConnectorID === undefined || awsConnectorID === null) {
        throw new Error("Missing the required parameter 'awsConnectorID' when calling describeAWSConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling describeAWSConnector");
      }


      var pathParams = {
        'awsConnectorID': awsConnectorID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AWSConnector;

      return this.apiClient.callApi(
        '/awsconnectors/{awsConnectorID}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Describe an existing AWS Connector
     * Describe an AWS Connector by ID.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AWSConnector}
     */
    this.describeAWSConnector = function(awsConnectorID, apiVersion) {
      return this.describeAWSConnectorWithHttpInfo(awsConnectorID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List AWS Connectors
     * Lists all AWS Connectors.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AWSConnectors} and HTTP response
     */
    this.listAWSConnectorsWithHttpInfo = function(apiVersion) {
      var postBody = null;

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listAWSConnectors");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AWSConnectors;

      return this.apiClient.callApi(
        '/awsconnectors', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List AWS Connectors
     * Lists all AWS Connectors.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AWSConnectors}
     */
    this.listAWSConnectors = function(apiVersion) {
      return this.listAWSConnectorsWithHttpInfo(apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Modify an AWS Connector
     * Modify the specified AWS Connector by ID. Any unset elements will be left unchanged.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to modify.
     * @param {module:model/AWSConnector} awsConnector The settings of the AWS Connector to modify.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.sync Immediately trigger a synchronization for the AWS Connector.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AWSConnector} and HTTP response
     */
    this.modifyAWSConnectorWithHttpInfo = function(awsConnectorID, awsConnector, apiVersion, opts) {
      opts = opts || {};
      var postBody = awsConnector;

      // verify the required parameter 'awsConnectorID' is set
      if (awsConnectorID === undefined || awsConnectorID === null) {
        throw new Error("Missing the required parameter 'awsConnectorID' when calling modifyAWSConnector");
      }

      // verify the required parameter 'awsConnector' is set
      if (awsConnector === undefined || awsConnector === null) {
        throw new Error("Missing the required parameter 'awsConnector' when calling modifyAWSConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling modifyAWSConnector");
      }


      var pathParams = {
        'awsConnectorID': awsConnectorID
      };
      var queryParams = {
        'sync': opts['sync'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AWSConnector;

      return this.apiClient.callApi(
        '/awsconnectors/{awsConnectorID}', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Modify an AWS Connector
     * Modify the specified AWS Connector by ID. Any unset elements will be left unchanged.
     * @param {Number} awsConnectorID The ID number of the AWS Connector to modify.
     * @param {module:model/AWSConnector} awsConnector The settings of the AWS Connector to modify.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.sync Immediately trigger a synchronization for the AWS Connector.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AWSConnector}
     */
    this.modifyAWSConnector = function(awsConnectorID, awsConnector, apiVersion, opts) {
      return this.modifyAWSConnectorWithHttpInfo(awsConnectorID, awsConnector, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Search AWS Connectors
     * Search for AWS Connectors using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AWSConnectors} and HTTP response
     */
    this.searchAWSConnectorsWithHttpInfo = function(apiVersion, opts) {
      opts = opts || {};
      var postBody = opts['searchFilter'];

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling searchAWSConnectors");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AWSConnectors;

      return this.apiClient.callApi(
        '/awsconnectors/search', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Search AWS Connectors
     * Search for AWS Connectors using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AWSConnectors}
     */
    this.searchAWSConnectors = function(apiVersion, opts) {
      return this.searchAWSConnectorsWithHttpInfo(apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }
  };

  return exports;
}));
