/**
 * Trend Micro Deep Security API
 * Copyright 2018 - 2024 Trend Micro Incorporated.<br/>Get protected, stay secured, and keep informed with Trend Micro Deep Security's new RESTful API. Access system data and manage security configurations to automate your security workflows and integrate Deep Security into your CI/CD pipeline. # Authentication <!-- ReDoc-Inject: <security-definitions> -->
 *
 * OpenAPI spec version: 20.0.904
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.4.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/AzureConnector', 'model/AzureConnectors', 'model/SearchFilter'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/AzureConnector'), require('../model/AzureConnectors'), require('../model/SearchFilter'));
  } else {
    // Browser globals (root is window)
    if (!root.Deepsecurity) {
      root.Deepsecurity = {};
    }
    root.Deepsecurity.AzureConnectorsApi = factory(root.Deepsecurity.ApiClient, root.Deepsecurity.AzureConnector, root.Deepsecurity.AzureConnectors, root.Deepsecurity.SearchFilter);
  }
}(this, function(ApiClient, AzureConnector, AzureConnectors, SearchFilter) {
  'use strict';

  /**
   * AzureConnectors service.
   * @module api/AzureConnectorsApi
   * @version 20.0.904
   */

  /**
   * Constructs a new AzureConnectorsApi. 
   * @alias module:api/AzureConnectorsApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;



    /**
     * Create an Azure Connector
     * Create a new Azure Connector.
     * @param {module:model/AzureConnector} azureConnector The settings of the new Azure Connector.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AzureConnector} and HTTP response
     */
    this.createAzureConnectorWithHttpInfo = function(azureConnector, apiVersion) {
      var postBody = azureConnector;

      // verify the required parameter 'azureConnector' is set
      if (azureConnector === undefined || azureConnector === null) {
        throw new Error("Missing the required parameter 'azureConnector' when calling createAzureConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling createAzureConnector");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AzureConnector;

      return this.apiClient.callApi(
        '/azureconnectors', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Create an Azure Connector
     * Create a new Azure Connector.
     * @param {module:model/AzureConnector} azureConnector The settings of the new Azure Connector.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AzureConnector}
     */
    this.createAzureConnector = function(azureConnector, apiVersion) {
      return this.createAzureConnectorWithHttpInfo(azureConnector, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Delete an Azure Connector
     * Delete an existing Azure Connector by ID.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */
    this.deleteAzureConnectorWithHttpInfo = function(azureConnectorID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'azureConnectorID' is set
      if (azureConnectorID === undefined || azureConnectorID === null) {
        throw new Error("Missing the required parameter 'azureConnectorID' when calling deleteAzureConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling deleteAzureConnector");
      }


      var pathParams = {
        'azureConnectorID': azureConnectorID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = null;

      return this.apiClient.callApi(
        '/azureconnectors/{azureConnectorID}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Delete an Azure Connector
     * Delete an existing Azure Connector by ID.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */
    this.deleteAzureConnector = function(azureConnectorID, apiVersion) {
      return this.deleteAzureConnectorWithHttpInfo(azureConnectorID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Describe an existing Azure Connector
     * Describe an Azure Connector by ID.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AzureConnector} and HTTP response
     */
    this.describeAzureConnectorWithHttpInfo = function(azureConnectorID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'azureConnectorID' is set
      if (azureConnectorID === undefined || azureConnectorID === null) {
        throw new Error("Missing the required parameter 'azureConnectorID' when calling describeAzureConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling describeAzureConnector");
      }


      var pathParams = {
        'azureConnectorID': azureConnectorID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AzureConnector;

      return this.apiClient.callApi(
        '/azureconnectors/{azureConnectorID}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Describe an existing Azure Connector
     * Describe an Azure Connector by ID.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AzureConnector}
     */
    this.describeAzureConnector = function(azureConnectorID, apiVersion) {
      return this.describeAzureConnectorWithHttpInfo(azureConnectorID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List Azure Connectors
     * Lists all Azure Connectors.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AzureConnectors} and HTTP response
     */
    this.listAzureConnectorsWithHttpInfo = function(apiVersion) {
      var postBody = null;

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listAzureConnectors");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AzureConnectors;

      return this.apiClient.callApi(
        '/azureconnectors', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List Azure Connectors
     * Lists all Azure Connectors.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AzureConnectors}
     */
    this.listAzureConnectors = function(apiVersion) {
      return this.listAzureConnectorsWithHttpInfo(apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Modify an Azure Connector
     * Modify the specified Azure Connector by ID. Any unset elements will be left unchanged. Property &#x60;azureTenantID&#x60;, &#x60;subscriptionID&#x60;, &#x60;loginApiEndPoint&#x60; and &#x60;resourceApiEndPoint&#x60; can&#39;t be modified.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to modify.
     * @param {module:model/AzureConnector} azureConnector The settings of the Azure Connector to modify.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.sync Immediately trigger a synchronization for the Azure Connector.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AzureConnector} and HTTP response
     */
    this.modifyAzureConnectorWithHttpInfo = function(azureConnectorID, azureConnector, apiVersion, opts) {
      opts = opts || {};
      var postBody = azureConnector;

      // verify the required parameter 'azureConnectorID' is set
      if (azureConnectorID === undefined || azureConnectorID === null) {
        throw new Error("Missing the required parameter 'azureConnectorID' when calling modifyAzureConnector");
      }

      // verify the required parameter 'azureConnector' is set
      if (azureConnector === undefined || azureConnector === null) {
        throw new Error("Missing the required parameter 'azureConnector' when calling modifyAzureConnector");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling modifyAzureConnector");
      }


      var pathParams = {
        'azureConnectorID': azureConnectorID
      };
      var queryParams = {
        'sync': opts['sync'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AzureConnector;

      return this.apiClient.callApi(
        '/azureconnectors/{azureConnectorID}', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Modify an Azure Connector
     * Modify the specified Azure Connector by ID. Any unset elements will be left unchanged. Property &#x60;azureTenantID&#x60;, &#x60;subscriptionID&#x60;, &#x60;loginApiEndPoint&#x60; and &#x60;resourceApiEndPoint&#x60; can&#39;t be modified.
     * @param {Number} azureConnectorID The ID number of the Azure Connector to modify.
     * @param {module:model/AzureConnector} azureConnector The settings of the Azure Connector to modify.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.sync Immediately trigger a synchronization for the Azure Connector.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AzureConnector}
     */
    this.modifyAzureConnector = function(azureConnectorID, azureConnector, apiVersion, opts) {
      return this.modifyAzureConnectorWithHttpInfo(azureConnectorID, azureConnector, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Search Azure Connectors
     * Search for Azure Connectors using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/AzureConnectors} and HTTP response
     */
    this.searchAzureConnectorsWithHttpInfo = function(apiVersion, opts) {
      opts = opts || {};
      var postBody = opts['searchFilter'];

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling searchAzureConnectors");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = AzureConnectors;

      return this.apiClient.callApi(
        '/azureconnectors/search', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Search Azure Connectors
     * Search for Azure Connectors using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/AzureConnectors}
     */
    this.searchAzureConnectors = function(apiVersion, opts) {
      return this.searchAzureConnectorsWithHttpInfo(apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }
  };

  return exports;
}));
