/**
 * Trend Micro Deep Security API
 * Copyright 2018 - 2024 Trend Micro Incorporated.<br/>Get protected, stay secured, and keep informed with Trend Micro Deep Security's new RESTful API. Access system data and manage security configurations to automate your security workflows and integrate Deep Security into your CI/CD pipeline. # Authentication <!-- ReDoc-Inject: <security-definitions> -->
 *
 * OpenAPI spec version: 20.0.904
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.4.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/ExceptionRules'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/ExceptionRules'));
  } else {
    // Browser globals (root is window)
    if (!root.Deepsecurity) {
      root.Deepsecurity = {};
    }
    root.Deepsecurity.ComputerDeviceControlExceptionRulesApi = factory(root.Deepsecurity.ApiClient, root.Deepsecurity.ExceptionRules);
  }
}(this, function(ApiClient, ExceptionRules) {
  'use strict';

  /**
   * ComputerDeviceControlExceptionRules service.
   * @module api/ComputerDeviceControlExceptionRulesApi
   * @version 20.0.904
   */

  /**
   * Constructs a new ComputerDeviceControlExceptionRulesApi. 
   * @alias module:api/ComputerDeviceControlExceptionRulesApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;



    /**
     * Add Device Exception Rules
     * Assign device exception rules to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {module:model/ExceptionRules} exceptionRules Exception Rules for the device.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ExceptionRules} and HTTP response
     */
    this.addExceptionRulesOnComputerWithHttpInfo = function(computerID, exceptionRules, apiVersion, opts) {
      opts = opts || {};
      var postBody = exceptionRules;

      // verify the required parameter 'computerID' is set
      if (computerID === undefined || computerID === null) {
        throw new Error("Missing the required parameter 'computerID' when calling addExceptionRulesOnComputer");
      }

      // verify the required parameter 'exceptionRules' is set
      if (exceptionRules === undefined || exceptionRules === null) {
        throw new Error("Missing the required parameter 'exceptionRules' when calling addExceptionRulesOnComputer");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling addExceptionRulesOnComputer");
      }


      var pathParams = {
        'computerID': computerID
      };
      var queryParams = {
        'overrides': opts['overrides'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = ExceptionRules;

      return this.apiClient.callApi(
        '/computers/{computerID}/devicecontrol/usbdeviceexceptionrules', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Add Device Exception Rules
     * Assign device exception rules to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {module:model/ExceptionRules} exceptionRules Exception Rules for the device.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ExceptionRules}
     */
    this.addExceptionRulesOnComputer = function(computerID, exceptionRules, apiVersion, opts) {
      return this.addExceptionRulesOnComputerWithHttpInfo(computerID, exceptionRules, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List Device Exception Rules
     * Lists all device exception rules assigned to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ExceptionRules} and HTTP response
     */
    this.listExceptionRulesOnComputerWithHttpInfo = function(computerID, apiVersion, opts) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'computerID' is set
      if (computerID === undefined || computerID === null) {
        throw new Error("Missing the required parameter 'computerID' when calling listExceptionRulesOnComputer");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listExceptionRulesOnComputer");
      }


      var pathParams = {
        'computerID': computerID
      };
      var queryParams = {
        'overrides': opts['overrides'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = ExceptionRules;

      return this.apiClient.callApi(
        '/computers/{computerID}/devicecontrol/usbdeviceexceptionrules', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List Device Exception Rules
     * Lists all device exception rules assigned to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ExceptionRules}
     */
    this.listExceptionRulesOnComputer = function(computerID, apiVersion, opts) {
      return this.listExceptionRulesOnComputerWithHttpInfo(computerID, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Remove a Device Exception Rule
     * Unassign a device exception rule from a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {Number} exceptionRuleID The ID number of the Exception Rule to delete.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ExceptionRules} and HTTP response
     */
    this.removeExceptionRuleOnComputerWithHttpInfo = function(computerID, exceptionRuleID, apiVersion, opts) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'computerID' is set
      if (computerID === undefined || computerID === null) {
        throw new Error("Missing the required parameter 'computerID' when calling removeExceptionRuleOnComputer");
      }

      // verify the required parameter 'exceptionRuleID' is set
      if (exceptionRuleID === undefined || exceptionRuleID === null) {
        throw new Error("Missing the required parameter 'exceptionRuleID' when calling removeExceptionRuleOnComputer");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling removeExceptionRuleOnComputer");
      }


      var pathParams = {
        'computerID': computerID,
        'exceptionRuleID': exceptionRuleID
      };
      var queryParams = {
        'overrides': opts['overrides'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = ExceptionRules;

      return this.apiClient.callApi(
        '/computers/{computerID}/devicecontrol/usbdeviceexceptionrules/{exceptionRuleID}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Remove a Device Exception Rule
     * Unassign a device exception rule from a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {Number} exceptionRuleID The ID number of the Exception Rule to delete.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ExceptionRules}
     */
    this.removeExceptionRuleOnComputer = function(computerID, exceptionRuleID, apiVersion, opts) {
      return this.removeExceptionRuleOnComputerWithHttpInfo(computerID, exceptionRuleID, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Set Device Exception Rules
     * Set device exception rules assigned to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {module:model/ExceptionRules} exceptionRules Exception Rules for the device.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ExceptionRules} and HTTP response
     */
    this.setExceptionRulesOnComputerWithHttpInfo = function(computerID, exceptionRules, apiVersion, opts) {
      opts = opts || {};
      var postBody = exceptionRules;

      // verify the required parameter 'computerID' is set
      if (computerID === undefined || computerID === null) {
        throw new Error("Missing the required parameter 'computerID' when calling setExceptionRulesOnComputer");
      }

      // verify the required parameter 'exceptionRules' is set
      if (exceptionRules === undefined || exceptionRules === null) {
        throw new Error("Missing the required parameter 'exceptionRules' when calling setExceptionRulesOnComputer");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling setExceptionRulesOnComputer");
      }


      var pathParams = {
        'computerID': computerID
      };
      var queryParams = {
        'overrides': opts['overrides'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = ExceptionRules;

      return this.apiClient.callApi(
        '/computers/{computerID}/devicecontrol/usbdeviceexceptionrules', 'PUT',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Set Device Exception Rules
     * Set device exception rules assigned to a computer.
     * @param {Number} computerID The ID number of the computer.
     * @param {module:model/ExceptionRules} exceptionRules Exception Rules for the device.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.overrides Return only Exception Rules directly related to the current computer.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ExceptionRules}
     */
    this.setExceptionRulesOnComputer = function(computerID, exceptionRules, apiVersion, opts) {
      return this.setExceptionRulesOnComputerWithHttpInfo(computerID, exceptionRules, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }
  };

  return exports;
}));
