/**
 * Trend Micro Deep Security API
 * Copyright 2018 - 2024 Trend Micro Incorporated.<br/>Get protected, stay secured, and keep informed with Trend Micro Deep Security's new RESTful API. Access system data and manage security configurations to automate your security workflows and integrate Deep Security into your CI/CD pipeline. # Authentication <!-- ReDoc-Inject: <security-definitions> -->
 *
 * OpenAPI spec version: 20.0.904
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.4.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/Proxies', 'model/Proxy', 'model/SearchFilter'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/Proxies'), require('../model/Proxy'), require('../model/SearchFilter'));
  } else {
    // Browser globals (root is window)
    if (!root.Deepsecurity) {
      root.Deepsecurity = {};
    }
    root.Deepsecurity.ProxiesApi = factory(root.Deepsecurity.ApiClient, root.Deepsecurity.Proxies, root.Deepsecurity.Proxy, root.Deepsecurity.SearchFilter);
  }
}(this, function(ApiClient, Proxies, Proxy, SearchFilter) {
  'use strict';

  /**
   * Proxies service.
   * @module api/ProxiesApi
   * @version 20.0.904
   */

  /**
   * Constructs a new ProxiesApi. 
   * @alias module:api/ProxiesApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;



    /**
     * Create a Proxy
     * Create a new proxy.
     * @param {module:model/Proxy} proxy The settings of the proxy to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/Proxy} and HTTP response
     */
    this.createProxyWithHttpInfo = function(proxy, apiVersion) {
      var postBody = proxy;

      // verify the required parameter 'proxy' is set
      if (proxy === undefined || proxy === null) {
        throw new Error("Missing the required parameter 'proxy' when calling createProxy");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling createProxy");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = Proxy;

      return this.apiClient.callApi(
        '/proxies', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Create a Proxy
     * Create a new proxy.
     * @param {module:model/Proxy} proxy The settings of the proxy to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/Proxy}
     */
    this.createProxy = function(proxy, apiVersion) {
      return this.createProxyWithHttpInfo(proxy, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Delete a Proxy
     * Delete a proxy by ID.
     * @param {Number} proxyID The ID number of the proxy to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */
    this.deleteProxyWithHttpInfo = function(proxyID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'proxyID' is set
      if (proxyID === undefined || proxyID === null) {
        throw new Error("Missing the required parameter 'proxyID' when calling deleteProxy");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling deleteProxy");
      }


      var pathParams = {
        'proxyID': proxyID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = null;

      return this.apiClient.callApi(
        '/proxies/{proxyID}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Delete a Proxy
     * Delete a proxy by ID.
     * @param {Number} proxyID The ID number of the proxy to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */
    this.deleteProxy = function(proxyID, apiVersion) {
      return this.deleteProxyWithHttpInfo(proxyID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Describe a Proxy
     * Describe a proxy by ID.
     * @param {Number} proxyID The ID number of the proxy to describe.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {String} opts.proxyType Type of proxy
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/Proxy} and HTTP response
     */
    this.describeProxyWithHttpInfo = function(proxyID, apiVersion, opts) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'proxyID' is set
      if (proxyID === undefined || proxyID === null) {
        throw new Error("Missing the required parameter 'proxyID' when calling describeProxy");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling describeProxy");
      }


      var pathParams = {
        'proxyID': proxyID
      };
      var queryParams = {
        'proxyType': opts['proxyType'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = Proxy;

      return this.apiClient.callApi(
        '/proxies/{proxyID}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Describe a Proxy
     * Describe a proxy by ID.
     * @param {Number} proxyID The ID number of the proxy to describe.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {String} opts.proxyType Type of proxy
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/Proxy}
     */
    this.describeProxy = function(proxyID, apiVersion, opts) {
      return this.describeProxyWithHttpInfo(proxyID, apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List Proxies
     * Lists all proxies.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.includesSG includes sg settings. default: false
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/Proxies} and HTTP response
     */
    this.listProxiesWithHttpInfo = function(apiVersion, opts) {
      opts = opts || {};
      var postBody = null;

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listProxies");
      }


      var pathParams = {
      };
      var queryParams = {
        'includesSG': opts['includesSG'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = Proxies;

      return this.apiClient.callApi(
        '/proxies', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List Proxies
     * Lists all proxies.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {Boolean} opts.includesSG includes sg settings. default: false
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/Proxies}
     */
    this.listProxies = function(apiVersion, opts) {
      return this.listProxiesWithHttpInfo(apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Modify a Proxy
     * Modify a proxy by ID. Any unset elements will be left unchanged.
     * @param {Number} proxyID The ID number of the proxy to modify.
     * @param {module:model/Proxy} proxy The settings of the proxy to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/Proxy} and HTTP response
     */
    this.modifyProxyWithHttpInfo = function(proxyID, proxy, apiVersion) {
      var postBody = proxy;

      // verify the required parameter 'proxyID' is set
      if (proxyID === undefined || proxyID === null) {
        throw new Error("Missing the required parameter 'proxyID' when calling modifyProxy");
      }

      // verify the required parameter 'proxy' is set
      if (proxy === undefined || proxy === null) {
        throw new Error("Missing the required parameter 'proxy' when calling modifyProxy");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling modifyProxy");
      }


      var pathParams = {
        'proxyID': proxyID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = Proxy;

      return this.apiClient.callApi(
        '/proxies/{proxyID}', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Modify a Proxy
     * Modify a proxy by ID. Any unset elements will be left unchanged.
     * @param {Number} proxyID The ID number of the proxy to modify.
     * @param {module:model/Proxy} proxy The settings of the proxy to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/Proxy}
     */
    this.modifyProxy = function(proxyID, proxy, apiVersion) {
      return this.modifyProxyWithHttpInfo(proxyID, proxy, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Search Proxies
     * Search for proxies using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @param {Boolean} opts.includesSG includes sg settings. default: false
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/Proxies} and HTTP response
     */
    this.searchProxiesWithHttpInfo = function(apiVersion, opts) {
      opts = opts || {};
      var postBody = opts['searchFilter'];

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling searchProxies");
      }


      var pathParams = {
      };
      var queryParams = {
        'includesSG': opts['includesSG'],
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = Proxies;

      return this.apiClient.callApi(
        '/proxies/search', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Search Proxies
     * Search for proxies using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @param {Boolean} opts.includesSG includes sg settings. default: false
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/Proxies}
     */
    this.searchProxies = function(apiVersion, opts) {
      return this.searchProxiesWithHttpInfo(apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }
  };

  return exports;
}));
