/**
 * Trend Micro Deep Security API
 * Copyright 2018 - 2024 Trend Micro Incorporated.<br/>Get protected, stay secured, and keep informed with Trend Micro Deep Security's new RESTful API. Access system data and manage security configurations to automate your security workflows and integrate Deep Security into your CI/CD pipeline. # Authentication <!-- ReDoc-Inject: <security-definitions> -->
 *
 * OpenAPI spec version: 20.0.904
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 *
 * Swagger Codegen version: 2.4.0-SNAPSHOT
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/ComputerExceptionRules', 'model/PolicyExceptionRules', 'model/SearchFilter', 'model/USBDevice', 'model/USBDevices'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/ComputerExceptionRules'), require('../model/PolicyExceptionRules'), require('../model/SearchFilter'), require('../model/USBDevice'), require('../model/USBDevices'));
  } else {
    // Browser globals (root is window)
    if (!root.Deepsecurity) {
      root.Deepsecurity = {};
    }
    root.Deepsecurity.USBStorageDevicesApi = factory(root.Deepsecurity.ApiClient, root.Deepsecurity.ComputerExceptionRules, root.Deepsecurity.PolicyExceptionRules, root.Deepsecurity.SearchFilter, root.Deepsecurity.USBDevice, root.Deepsecurity.USBDevices);
  }
}(this, function(ApiClient, ComputerExceptionRules, PolicyExceptionRules, SearchFilter, USBDevice, USBDevices) {
  'use strict';

  /**
   * USBStorageDevices service.
   * @module api/USBStorageDevicesApi
   * @version 20.0.904
   */

  /**
   * Constructs a new USBStorageDevicesApi. 
   * @alias module:api/USBStorageDevicesApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;



    /**
     * Create a USB Storage Device
     * Create a new USB storage device.
     * @param {module:model/USBDevice} device The settings of the USB storage device to create.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/USBDevice} and HTTP response
     */
    this.createUSBDeviceWithHttpInfo = function(device, apiVersion) {
      var postBody = device;

      // verify the required parameter 'device' is set
      if (device === undefined || device === null) {
        throw new Error("Missing the required parameter 'device' when calling createUSBDevice");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling createUSBDevice");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = USBDevice;

      return this.apiClient.callApi(
        '/usbdevices', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Create a USB Storage Device
     * Create a new USB storage device.
     * @param {module:model/USBDevice} device The settings of the USB storage device to create.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/USBDevice}
     */
    this.createUSBDevice = function(device, apiVersion) {
      return this.createUSBDeviceWithHttpInfo(device, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Delete a USB Storage Device
     * Delete a USB storage device by ID.
     * @param {Number} deviceID The ID number of the USB storage device to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing HTTP response
     */
    this.deleteUSBDeviceWithHttpInfo = function(deviceID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'deviceID' is set
      if (deviceID === undefined || deviceID === null) {
        throw new Error("Missing the required parameter 'deviceID' when calling deleteUSBDevice");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling deleteUSBDevice");
      }


      var pathParams = {
        'deviceID': deviceID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = null;

      return this.apiClient.callApi(
        '/usbdevices/{deviceID}', 'DELETE',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Delete a USB Storage Device
     * Delete a USB storage device by ID.
     * @param {Number} deviceID The ID number of the USB storage device to delete.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}
     */
    this.deleteUSBDevice = function(deviceID, apiVersion) {
      return this.deleteUSBDeviceWithHttpInfo(deviceID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Describe a USB Storage Device
     * Describe a USB storage device by ID.
     * @param {Number} deviceID The ID number of the USB storage device to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/USBDevice} and HTTP response
     */
    this.describeUSBDeviceWithHttpInfo = function(deviceID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'deviceID' is set
      if (deviceID === undefined || deviceID === null) {
        throw new Error("Missing the required parameter 'deviceID' when calling describeUSBDevice");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling describeUSBDevice");
      }


      var pathParams = {
        'deviceID': deviceID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = USBDevice;

      return this.apiClient.callApi(
        '/usbdevices/{deviceID}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Describe a USB Storage Device
     * Describe a USB storage device by ID.
     * @param {Number} deviceID The ID number of the USB storage device to describe.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/USBDevice}
     */
    this.describeUSBDevice = function(deviceID, apiVersion) {
      return this.describeUSBDeviceWithHttpInfo(deviceID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List Device Exception Rules
     * Lists device exception rules for this device assigned to computers.
     * @param {Number} deviceID The ID number of the USB storage device.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/ComputerExceptionRules} and HTTP response
     */
    this.listComputerExceptionRulesWithHttpInfo = function(deviceID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'deviceID' is set
      if (deviceID === undefined || deviceID === null) {
        throw new Error("Missing the required parameter 'deviceID' when calling listComputerExceptionRules");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listComputerExceptionRules");
      }


      var pathParams = {
        'deviceID': deviceID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = ComputerExceptionRules;

      return this.apiClient.callApi(
        '/usbdevices/{deviceID}/computerexceptionrules', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List Device Exception Rules
     * Lists device exception rules for this device assigned to computers.
     * @param {Number} deviceID The ID number of the USB storage device.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/ComputerExceptionRules}
     */
    this.listComputerExceptionRules = function(deviceID, apiVersion) {
      return this.listComputerExceptionRulesWithHttpInfo(deviceID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List Device Exception Rules
     * Lists device exception rules for this device assigned to policies.
     * @param {Number} deviceID The ID number of the USB storage device.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/PolicyExceptionRules} and HTTP response
     */
    this.listPolicyExceptionRulesWithHttpInfo = function(deviceID, apiVersion) {
      var postBody = null;

      // verify the required parameter 'deviceID' is set
      if (deviceID === undefined || deviceID === null) {
        throw new Error("Missing the required parameter 'deviceID' when calling listPolicyExceptionRules");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listPolicyExceptionRules");
      }


      var pathParams = {
        'deviceID': deviceID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = PolicyExceptionRules;

      return this.apiClient.callApi(
        '/usbdevices/{deviceID}/policyexceptionrules', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List Device Exception Rules
     * Lists device exception rules for this device assigned to policies.
     * @param {Number} deviceID The ID number of the USB storage device.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/PolicyExceptionRules}
     */
    this.listPolicyExceptionRules = function(deviceID, apiVersion) {
      return this.listPolicyExceptionRulesWithHttpInfo(deviceID, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * List USB Storage Devices
     * Lists all USB storage devices.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/USBDevices} and HTTP response
     */
    this.listUSBDevicesWithHttpInfo = function(apiVersion) {
      var postBody = null;

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling listUSBDevices");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = USBDevices;

      return this.apiClient.callApi(
        '/usbdevices', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * List USB Storage Devices
     * Lists all USB storage devices.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/USBDevices}
     */
    this.listUSBDevices = function(apiVersion) {
      return this.listUSBDevicesWithHttpInfo(apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Modify a USB Storage Device
     * Modify a USB storage device by ID. Any unset elements will be left unchanged.
     * @param {Number} deviceID The ID number of the USB storage device to modify.
     * @param {module:model/USBDevice} device The settings of the USB storage device to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/USBDevice} and HTTP response
     */
    this.modifyUSBDeviceWithHttpInfo = function(deviceID, device, apiVersion) {
      var postBody = device;

      // verify the required parameter 'deviceID' is set
      if (deviceID === undefined || deviceID === null) {
        throw new Error("Missing the required parameter 'deviceID' when calling modifyUSBDevice");
      }

      // verify the required parameter 'device' is set
      if (device === undefined || device === null) {
        throw new Error("Missing the required parameter 'device' when calling modifyUSBDevice");
      }

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling modifyUSBDevice");
      }


      var pathParams = {
        'deviceID': deviceID
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = USBDevice;

      return this.apiClient.callApi(
        '/usbdevices/{deviceID}', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Modify a USB Storage Device
     * Modify a USB storage device by ID. Any unset elements will be left unchanged.
     * @param {Number} deviceID The ID number of the USB storage device to modify.
     * @param {module:model/USBDevice} device The settings of the USB storage device to modify.
     * @param {String} apiVersion The version of the api being called.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/USBDevice}
     */
    this.modifyUSBDevice = function(deviceID, device, apiVersion) {
      return this.modifyUSBDeviceWithHttpInfo(deviceID, device, apiVersion)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }


    /**
     * Search USB Storage Devices
     * Search for USB storage devices using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with an object containing data of type {@link module:model/USBDevices} and HTTP response
     */
    this.searchUSBDevicesWithHttpInfo = function(apiVersion, opts) {
      opts = opts || {};
      var postBody = opts['searchFilter'];

      // verify the required parameter 'apiVersion' is set
      if (apiVersion === undefined || apiVersion === null) {
        throw new Error("Missing the required parameter 'apiVersion' when calling searchUSBDevices");
      }


      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
        'api-version': apiVersion
      };
      var formParams = {
      };

      var authNames = ['DefaultAuthentication'];
      var contentTypes = ['application/json'];
      var accepts = ['application/json'];
      var returnType = USBDevices;

      return this.apiClient.callApi(
        '/usbdevices/search', 'POST',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType
      );
    }

    /**
     * Search USB Storage Devices
     * Search for USB storage devices using optional filters.
     * @param {String} apiVersion The version of the api being called.
     * @param {Object} opts Optional parameters
     * @param {module:model/SearchFilter} opts.searchFilter A collection of options used to filter the search results.
     * @return {Promise} a {@link https://www.promisejs.org/|Promise}, with data of type {@link module:model/USBDevices}
     */
    this.searchUSBDevices = function(apiVersion, opts) {
      return this.searchUSBDevicesWithHttpInfo(apiVersion, opts)
        .then(function(response_and_data) {
          return response_and_data.data;
        });
    }
  };

  return exports;
}));
